@@ -1,7 +1,7 @@
 #' Learner for training random forests for classification problems
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v2.1.0/Heuristics/reference/#IAI.RandomForestClassifier}{\code{IAI.RandomForestClassifier}}
+#' \href{https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.RandomForestClassifier}{\code{IAI.RandomForestClassifier}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -21,7 +21,7 @@ random_forest_classifier <- function(...) {
 #' Learner for training random forests for regression problems
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v2.1.0/Heuristics/reference/#IAI.RandomForestRegressor}{\code{IAI.RandomForestRegressor}}
+#' \href{https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.RandomForestRegressor}{\code{IAI.RandomForestRegressor}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -38,10 +38,30 @@ random_forest_regressor <- function(...) {
 }
 
 
+#' Learner for training random forests for survival problems
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.RandomForestSurvivalLearner}{\code{IAI.RandomForestSurvivalLearner}}
+#'
+#' @param ... Use keyword arguments to set parameters on the resulting learner.
+#'            Refer to the Julia documentation for available parameters.
+#'
+#' @examples \dontrun{lnr <- iai::random_forest_survival_learner()}
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 2.2 or higher.
+#'
+#' @export
+random_forest_survival_learner <- function(...) {
+  requires_iai_version("2.2.0", "random_forest_survival_learner")
+  set_obj_class(jl_func("IAI.RandomForestSurvivalLearner_convert", ...))
+}
+
+
 #' Learner for training XGBoost models for classification problems
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v2.1.0/Heuristics/reference/#IAI.XGBoostClassifier}{\code{IAI.XGBoostClassifier}}
+#' \href{https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.XGBoostClassifier}{\code{IAI.XGBoostClassifier}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -61,7 +81,7 @@ xgboost_classifier <- function(...) {
 #' Learner for training XGBoost models for regression problems
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v2.1.0/Heuristics/reference/#IAI.XGBoostRegressor}{\code{IAI.XGBoostRegressor}}
+#' \href{https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.XGBoostRegressor}{\code{IAI.XGBoostRegressor}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -78,10 +98,30 @@ xgboost_regressor <- function(...) {
 }
 
 
+#' Learner for training XGBoost models for survival problems
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.XGBoostSurvivalLearner}{\code{IAI.XGBoostSurvivalLearner}}
+#'
+#' @param ... Use keyword arguments to set parameters on the resulting learner.
+#'            Refer to the Julia documentation for available parameters.
+#'
+#' @examples \dontrun{lnr <- iai::xgboost_survival_learner()}
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 2.2 or higher.
+#'
+#' @export
+xgboost_survival_learner <- function(...) {
+  requires_iai_version("2.2.0", "xgboost_survival_learner")
+  set_obj_class(jl_func("IAI.XGBoostSurvivalLearner_convert", ...))
+}
+
+
 #' Write the internal booster saved in the learner to file
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v2.1.0/Heuristics/reference/#IAI.write_booster}{\code{IAI.write_booster}}
+#' \href{https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.write_booster}{\code{IAI.write_booster}}
 #'
 #' @param filename Where to save the output.
 #' @param lnr The XGBoost learner with the booster to output.
@@ -98,10 +138,34 @@ write_booster <- function(filename, lnr) {
 }
 
 
+#' Calculate SHAP values for all points in the features using the learner
+#'
+#' Julia Equivalent:
+#' \href{https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.predict_shap}{\code{IAI.predict_shap}}
+#'
+#' @param lnr The XGBoost learner or grid to use for prediction.
+#' @param X The features of the data.
+#'
+#' @examples \dontrun{iai::predict_shap(lnr, X)}
+#'
+#' @section IAI Compatibility:
+#' Requires IAI version 2.2 or higher.
+#'
+#' @export
+predict_shap <- function(lnr, X) {
+  requires_iai_version("2.2.0", "predict_shap")
+  out <- jl_func("IAI.predict_shap_convert", lnr, X)
+  if (!is.matrix(out$shap_values)) {
+    out$shap_values <- as.list(out$shap_values)
+  }
+  out
+}
+
+
 #' Learner for training GLMNet models for regression problems
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v2.1.0/Heuristics/reference/#IAI.GLMNetCVRegressor}{\code{IAI.GLMNetCVRegressor}}
+#' \href{https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.GLMNetCVRegressor}{\code{IAI.GLMNetCVRegressor}}
 #'
 #' @param ... Use keyword arguments to set parameters on the resulting learner.
 #'            Refer to the Julia documentation for available parameters.
@@ -121,7 +185,7 @@ glmnetcv_regressor <- function(...) {
 #' Return the number of fits along the path in the trained learner
 #'
 #' Julia Equivalent:
-#' \href{https://docs.interpretable.ai/v2.1.0/Heuristics/reference/#IAI.get_num_fits}{\code{IAI.get_num_fits}}
+#' \href{https://docs.interpretable.ai/v2.2.0/Heuristics/reference/#IAI.get_num_fits}{\code{IAI.get_num_fits}}
 #'
 #' @param lnr The GLMNet learner to query.
 #'
